==> jc-1.4.0.tar.gz: soot/jimple/toolkits/pointer/nativemethods/JavaLangSecurityManagerNative.h <==
// public class soot.jimple.toolkits.pointer.nativemethods.JavaLangSecurityManagerNative

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1d68a82f28f88096 soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative
// @dep_class adf075d6a4c28634 soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass

// header file dependencies
// @dep_header soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass

#include "soot/jimple/toolkits/pointer/nativemethods/NativeMethodClass.h"

#ifndef _JC_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative_H_
#define _JC_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$object;
struct _jc_soot_jimple_toolkits_pointer_representations_ReferenceVariable$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$sub_refs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$refs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$object	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$vmethods	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$vtable	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$vtype	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$method$simulateMethod$16021ad0ff992382(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$method_info$simulateMethod$16021ad0ff992382;

// Static methods
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$method$java__5flang__5fSecurityManager__5fcurrentClassLoader0$1654630323b0a815(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *);
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$method$java__5flang__5fSecurityManager__5fcurrentLoadedClass0$d1753ad2ae2b825f(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *);
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$method$java__5flang__5fSecurityManager__5fgetClassContext$47bcd5147df2e74e(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *);
extern struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$object *_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$method$v$18d5b601de60d338(_jc_env *);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$vmethods {
	void	(*simulateMethod$16021ad0ff992382)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *);
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$vmethods	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$vmethods	soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$refs {
    _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$sub_refs	soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative;
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_refs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_nonrefs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
    _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$sub_nonrefs	soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$object {
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$vtype _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/pointer/nativemethods/JavaLangSecurityManagerNative.h <==
// public class soot.jimple.toolkits.pointer.nativemethods.JavaLangSecurityManagerNative

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1d68a82f28f88096 soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative
// @dep_class adf075d6a4c28634 soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass

// header file dependencies
// @dep_header soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass

#include "soot/jimple/toolkits/pointer/nativemethods/NativeMethodClass.h"

#ifndef _JC_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative_H_
#define _JC_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$object;
struct _jc_soot_jimple_toolkits_pointer_representations_ReferenceVariable$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$sub_refs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$refs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$object	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$vmethods	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$vtable	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$vtype	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$method$simulateMethod$16021ad0ff992382(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$method_info$simulateMethod$16021ad0ff992382;

// Static methods
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$method$java__5flang__5fSecurityManager__5fcurrentClassLoader0$1654630323b0a815(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$method$java__5flang__5fSecurityManager__5fcurrentLoadedClass0$d1753ad2ae2b825f(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$method$java__5flang__5fSecurityManager__5fgetClassContext$47bcd5147df2e74e(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$object *_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$method$v$18d5b601de60d338(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$vmethods {
	void	(*simulateMethod$16021ad0ff992382)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$vmethods	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$vmethods	soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$refs {
    _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$sub_refs	soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative;
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_refs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_nonrefs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
    _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$sub_nonrefs	soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$object {
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$vtype _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_nativemethods_JavaLangSecurityManagerNative_H_ */
